@@ -1,4 +1,4 @@
-/* Copyright 2012 Naikel Aparicio. All rights reserved.
+/* Copyright 2013 Naikel Aparicio. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
@@ -22,8 +22,8 @@
  * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  * The views and conclusions contained in the software and documentation
- * are those of the authors and should not be interpreted as representing
- * official policies, either expressed or implied, of Eeli Reilin.
+ * are those of the author and should not be interpreted as representing
+ * official policies, either expressed or implied, of the copyright holder.
  */
 
 #ifndef CHATAREA_H
@@ -53,12 +53,14 @@ signals:
     void topReached();
     void updateTimestamps();
     void mediaDownload(FMessage message);
+    void voiceNotePlayed(FMessage message);
     void contextMenuRequested(QPoint p, QObject *obj);
 
 public slots:
     void insertMessageAtTop(FMessage message);
     void insertMessageAtBottom(FMessage message);
     void mediaDownloadHandler(FMessage message);
+    void voiceNotePlayedHandler(FMessage message);
     void updateStatus(FMessage message);
     void updateProgress(FMessage message, float p);
     void updateUri(FMessage message);
